FindInPath

Trait FindInPath 

pub trait FindInPath {
    // Required method
    fn find_in_path(&self) -> Option<PathBuf>;
}
Allows finding in the PATH

Any type that implements this trait can be turned into a PathBuf to a valid executable found with the PATH environment variable.

Required Methods

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl FindInPath for &Path

Source

impl FindInPath for &str

Source

impl FindInPath for PathBuf

Source

impl FindInPath for String

Implementors