pub trait FindInPath {
// Required method
fn find_in_path(&self) -> Option<PathBuf>;
}Expand description
Allows finding in the PATH
Any type that implements this trait can be turned into a PathBuf to a valid executable found with the PATH environment variable.
Required Methods
fn find_in_path(&self) -> Option<PathBuf>
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".